import {app, BrowserWindow} from "electron";
import * as path from "path";
import {Server} from "./server";
import * as process from "process";
import {GPIO} from "./gpio";
import {PythonWebcam} from "./python_webcam";
import {FileHandler} from "./file_handler";

function createWindow() {
    // Create the browser window.
    const mainWindow = new BrowserWindow({
        height: 1080,
        webPreferences: {
            preload: path.join(__dirname, "preload.js"),
        },
        width: 1920,
        fullscreenable: true,
        fullscreen: true,
        closable: true,
        autoHideMenuBar: true,
    });

    // and load the index.html of the app.
    mainWindow.loadFile(path.join(__dirname, "../html/index.html"));

    // Open the DevTools.
    //mainWindow.webContents.openDevTools();
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.whenReady().then(() => {
    createWindow();
});

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on("window-all-closed", () => {
    app.quit();
});

// In this file you can include the rest of your app"s specific main process
// code. You can also put them in separate files and require them here.

Server.initServer().then();
PythonWebcam.startPythonService();

/*setInterval(() => {
    capture()
}, 1000*10);*/



try {
    // Capture button
    GPIO.watchForButton(10, (pin) => {
        Main.capture()
    });

    // Delete button
    GPIO.watchForButton(11, (pin) => {
        console.log("Delete fired!");

    });
} catch (e) {
    console.error("Could not bind gpio ports");
}

process.on("SIGINT", _ => {
    GPIO.unexportAll();
});


export class Main {

    private static port = GPIO.getPin(20, 'out')
    static async delete_last() {
        console.log("Delete fired!");

        let last_shots = await FileHandler.getLastImages();
        let last = last_shots[0];

        if(last.locked) {
            Server.io.emit("deleting", false);
        }
        else
        {
            Server.io.emit("deleting", true);
            await FileHandler.deleteLastImage();
            await Server.sendRecentPhotos();
        }
    }

    static capture() {
        console.log("Capture fired!");
        Server.io.emit("capturing", 3);

        setTimeout( async () => {
            this.port.setHigh();
        }, 2300 );
        setTimeout(async () => {
            let base64_string = await PythonWebcam.captureImage();
            Server.io.emit("captured", base64_string);
            this.port.setLow();
        }, 3000);
    }

}