import {Socket} from "socket.io";
import {FileHandler} from "./file_handler";
import {PythonWebcam} from "./python_webcam";
import {Main} from "./main";

export class Server {
    private static app = require("express")();
    private static server = require('http').createServer(this.app);
    public static io = require('socket.io')(this.server);
    private static interval : NodeJS.Timer;

    public static initServer(): Promise<void> {
        return new Promise((resolve, reject) => {
            // Socket.IO-Verbindung herstellen
            this.io.on('connection', async (socket: Socket) => {
                console.log('Client connected');
                await this.sendRecentPhotos();

                socket.on("do_shot", () => {
                    console.log("Capture fired!");
                    Server.io.emit("capturing", "");

                    setTimeout(async () => {
                        let base64_string = await PythonWebcam.captureImage();
                        Server.io.emit("captured", base64_string);
                    }, 3000);
                });
                socket.on("do_delete", () => {
                    Main.delete_last();
                })

            });



            //Webcam.startCameraStream();
            this.server.listen(3000);

            this.startInterval();
        });

    }

    public static async sendRecentPhotos()
    {
        let lastImages = await FileHandler.getLastImages();
        console.log("Sending last shots... " );
        this.io.emit('last_shots', lastImages);
    }


    public static startInterval(){
        setTimeout(async () => {
            try {
                this.io.emit("stream", (await PythonWebcam.getImage()));
            } catch( e )
            {
            }
            this.startInterval();
        }, 1000/30);
    }


}