import {io} from "socket.io-client";


let isShowingCaptured = false;


function openModal(title: string, text: string, closeTimeout = 4000 )
{
    let modal = document.getElementById("myModal");
    let modalTitle = document.getElementById("modalTitle");
    let modalText = document.getElementById("modalText");
    modalTitle.innerText = title;
    modalText.innerHTML = text;
    modal.style.display = "block";
    let t = setTimeout( () => {
        modal.style.display = "none";
    }, closeTimeout );


    let modalClose = document.getElementById("modalClose");
    modalClose.onclick = () => {
        clearTimeout(t);
        modal.style.display = "none";
    }

}

document.addEventListener("DOMContentLoaded", () => {
    const imageElement = document.getElementById('imageElement') as HTMLImageElement;
    const lastImages = document.getElementById('lastImages') as HTMLImageElement;
    const countdown = document.getElementById("countdown") as HTMLParagraphElement;
    const flash = document.getElementById("flash");
    const capture_btn = document.getElementById("capture");
    const del_btn = document.getElementById("delete");

    let socket = io("http://localhost:3000");

    socket.on("stream", (data) => {
        //console.log(data);
        if (isShowingCaptured) return;

        imageElement.src = data;
    });

    socket.on("last_shots", (data: { image: string, locked: boolean }[]) => {
        lastImages.innerHTML = "";
        for (let last of data) {
            let img = document.createElement("img");
            img.src = last.image;
            img.classList.add("lastImageImg");
            img.alt = "Bild wird geladen...";

            let lock = document.createElement("img");
            lock.src = last.locked ? "../images/lock.png" : "../images/broken.png";
            lock.classList.add("lastImageLock");
            lock.alt = "[Lock]";

            let div = document.createElement("div");
            div.classList.add("lastImage");
            div.append(img);
            div.onclick = () => {
                openModal("Foto Ansicht", `<img src="${last.image}" style="width: 90%">`, 1000 * 15 );
            }

            div.append(lock);

            if (data[0] == last) {
                div.classList.add("slowFadeInAnimation");
                 setTimeout(() => lastImages.prepend(div), 500);
            } else
                lastImages.append(div);

        }

    });

    socket.on('capturing', (data) => {
        countdown.innerText = "3";
        setTimeout(() => {
            countdown.innerText = "2";
            setTimeout(() => {
                countdown.innerText = "1";
                setTimeout(() => {
                    countdown.innerText = "CHEESE!";
                    setTimeout(() => {
                        flash.style.display = "block";
                    }, 150);
                }, 800);
            }, 950);
        }, 1000)
    });

    socket.on('captured', (data) => {
        isShowingCaptured = true;
        flash.style.display = "none";

        imageElement.src = data;
        setTimeout(() => {
            countdown.innerText = "";
        }, 250);

        setTimeout(() => isShowingCaptured = false, 3000);
    });

    socket.on('deleting', (data: boolean) => {
        if(!data)
        {
            openModal("Löschen nicht möglich!", "Foto kann nicht entfernt werden, da es bereits zu alt ist.<br>Wende dich bei Fragen an Tobi");
        }
        else
        {
            openModal("Löschen erfolgreich!", "Foto wurde unwiderruflich entfernt.");
        }
    });


    capture_btn.onclick = () => {
        socket.emit("do_shot");
    }
    del_btn.onclick = () => {
        socket.emit("do_delete");
    }
});



